<?php
/**
 * @brief ImgWidthAndHeightAdder, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author Julien Mudry and contributors
 *
 * @copyright Julien Mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
if (!defined('DC_RC_PATH')) {
    return;
}

Clearbricks::lib()->autoload([
    'imgWidthHeightAdder' => __DIR__ . '/inc/class.imgWidthHeightAdder.php',
    'iwahaMedia'          => __DIR__ . '/inc/class.iwahaMedia.php',
]);

/* Add behavior callback, will be used for all types of posts (standard, page, galery item, ...) */
dcCore::app()->addBehavior('coreAfterPostContentFormat', ['iwahaAdminBehaviors','afterPostFormat']);

/* Add behavior for the checkbox in the admin preferences */
dcCore::app()->addBehavior('adminBlogPreferencesFormV2', ['iwahaAdminBehaviors','adminBlogPreferencesForm']);
dcCore::app()->addBehavior('adminBeforeBlogSettingsUpdate', ['iwahaAdminBehaviors','adminBeforeBlogSettingsUpdate']);

class iwahaAdminBehaviors
{
    public static function afterPostFormat($ref)
    {
        dcCore::app()->blog->settings->addNamespace('iwaha');
        if (!dcCore::app()->blog->settings->iwaha->iwaha_enabled) {
            return;
        }

        $post_excerpt_xhtml = $ref['excerpt_xhtml'];
        $post_content_xhtml = $ref['content_xhtml'];

        imgWidthHeightAdder::updatePostEntries([
            'excerpt_xhtml' => &$post_excerpt_xhtml,
            'content_xhtml' => &$post_content_xhtml,
        ]);

        if ($post_excerpt_xhtml != $ref['excerpt_xhtml'] || $post_content_xhtml != $ref['content_xhtml']) {
            $ref['excerpt_xhtml'] = $post_excerpt_xhtml;
            $ref['content_xhtml'] = $post_content_xhtml;
        }
    }

    public static function adminBlogPreferencesForm(dcSettings $settings): void
    {
        dcCore::app()->blog->settings->addNamespace('iwaha');
        echo
        '<div class="fieldset" id="iwaha"><h4>IWaHa (Img Width and Height adder)</h4>' .
        '<p><label class="classic">' .
        form::checkbox('iwaha_enabled', '1', $settings->iwaha->iwaha_enabled) .
        __('Add width and height attributes to images in posts.') . '</label></p>' .
        '</div>';
    }

    public static function adminBeforeBlogSettingsUpdate(dcSettings $settings): void
    {
        $settings->addNamespace('iwaha');
        $settings->iwaha->put('iwaha_enabled', !empty($_POST['iwaha_enabled']), 'boolean');
    }
}
